@@ -104,7 +104,10 @@ namespace Aws
                 }
             }
 
-            Credentials::operator bool() const noexcept { return m_credentials != nullptr; }
+            Credentials::operator bool() const noexcept
+            {
+                return m_credentials != nullptr;
+            }
 
             CredentialsProvider::CredentialsProvider(aws_credentials_provider *provider, Allocator *allocator) noexcept
                 : m_allocator(allocator), m_provider(provider)
@@ -256,9 +259,8 @@ namespace Aws
                 std::for_each(
                     config.Providers.begin(),
                     config.Providers.end(),
-                    [&](const std::shared_ptr<ICredentialsProvider> &provider) {
-                        providers.push_back(provider->GetUnderlyingHandle());
-                    });
+                    [&](const std::shared_ptr<ICredentialsProvider> &provider)
+                    { providers.push_back(provider->GetUnderlyingHandle()); });
 
                 struct aws_credentials_provider_chain_options raw_config;
                 AWS_ZERO_STRUCT(raw_config);
@@ -474,5 +476,5 @@ namespace Aws
                 return s_CreateWrappedProvider(aws_credentials_provider_new_sts(allocator, &raw_config), allocator);
             }
         } // namespace Auth
-    }     // namespace Crt
+    } // namespace Crt
 } // namespace Aws
